from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from amphora_api_client.api.activities_api import ActivitiesApi
from amphora_api_client.api.amphorae_api import AmphoraeApi
from amphora_api_client.api.applications_api import ApplicationsApi
from amphora_api_client.api.authentication_api import AuthenticationApi
from amphora_api_client.api.geo_api import GeoApi
from amphora_api_client.api.identity_api import IdentityApi
from amphora_api_client.api.organisations_api import OrganisationsApi
from amphora_api_client.api.permission_api import PermissionApi
from amphora_api_client.api.search_api import SearchApi
from amphora_api_client.api.terms_of_use_api import TermsOfUseApi
from amphora_api_client.api.time_series_api import TimeSeriesApi
from amphora_api_client.api.users_api import UsersApi
from amphora_api_client.api.version_api import VersionApi
